var SvelteFa = (function () {
  'use strict';

  function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    subClass.__proto__ = superClass;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };
    return _getPrototypeOf(o);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;
      return o;
    };

    return _setPrototypeOf(o, p);
  }

  function isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  function _construct(Parent, args, Class) {
    if (isNativeReflectConstruct()) {
      _construct = Reflect.construct;
    } else {
      _construct = function _construct(Parent, args, Class) {
        var a = [null];
        a.push.apply(a, args);
        var Constructor = Function.bind.apply(Parent, a);
        var instance = new Constructor();
        if (Class) _setPrototypeOf(instance, Class.prototype);
        return instance;
      };
    }

    return _construct.apply(null, arguments);
  }

  function _isNativeFunction(fn) {
    return Function.toString.call(fn).indexOf("[native code]") !== -1;
  }

  function _wrapNativeSuper(Class) {
    var _cache = typeof Map === "function" ? new Map() : undefined;

    _wrapNativeSuper = function _wrapNativeSuper(Class) {
      if (Class === null || !_isNativeFunction(Class)) return Class;

      if (typeof Class !== "function") {
        throw new TypeError("Super expression must either be null or a function");
      }

      if (typeof _cache !== "undefined") {
        if (_cache.has(Class)) return _cache.get(Class);

        _cache.set(Class, Wrapper);
      }

      function Wrapper() {
        return _construct(Class, arguments, _getPrototypeOf(this).constructor);
      }

      Wrapper.prototype = Object.create(Class.prototype, {
        constructor: {
          value: Wrapper,
          enumerable: false,
          writable: true,
          configurable: true
        }
      });
      return _setPrototypeOf(Wrapper, Class);
    };

    return _wrapNativeSuper(Class);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }

    return self;
  }

  function noop() {}

  function assign(tar, src) {
    // @ts-ignore
    for (var k in src) {
      tar[k] = src[k];
    }

    return tar;
  }

  function run(fn) {
    return fn();
  }

  function blank_object() {
    return Object.create(null);
  }

  function run_all(fns) {
    fns.forEach(run);
  }

  function is_function(thing) {
    return typeof thing === 'function';
  }

  function safe_not_equal(a, b) {
    return a != a ? b == b : a !== b || a && typeof a === 'object' || typeof a === 'function';
  }

  function exclude_internal_props(props) {
    var result = {};

    for (var k in props) {
      if (k[0] !== '$') result[k] = props[k];
    }

    return result;
  }

  function append(target, node) {
    target.appendChild(node);
  }

  function insert(target, node, anchor) {
    target.insertBefore(node, anchor || null);
  }

  function detach(node) {
    node.parentNode.removeChild(node);
  }

  function svg_element(name) {
    return document.createElementNS('http://www.w3.org/2000/svg', name);
  }

  function text(data) {
    return document.createTextNode(data);
  }

  function empty() {
    return text('');
  }

  function attr(node, attribute, value) {
    if (value == null) node.removeAttribute(attribute);else node.setAttribute(attribute, value);
  }

  function set_attributes(node, attributes) {
    for (var key in attributes) {
      if (key === 'style') {
        node.style.cssText = attributes[key];
      } else if (key in node) {
        node[key] = attributes[key];
      } else {
        attr(node, key, attributes[key]);
      }
    }
  }

  function children(element) {
    return Array.from(element.childNodes);
  }

  var current_component;

  function set_current_component(component) {
    current_component = component;
  }

  var dirty_components = [];
  var binding_callbacks = [];
  var render_callbacks = [];
  var flush_callbacks = [];
  var resolved_promise = Promise.resolve();
  var update_scheduled = false;

  function schedule_update() {
    if (!update_scheduled) {
      update_scheduled = true;
      resolved_promise.then(flush);
    }
  }

  function add_render_callback(fn) {
    render_callbacks.push(fn);
  }

  function flush() {
    var seen_callbacks = new Set();

    do {
      // first, call beforeUpdate functions
      // and update components
      while (dirty_components.length) {
        var component = dirty_components.shift();
        set_current_component(component);
        update(component.$$);
      }

      while (binding_callbacks.length) {
        binding_callbacks.pop()();
      } // then, once components are updated, call
      // afterUpdate functions. This may cause
      // subsequent updates...


      for (var i = 0; i < render_callbacks.length; i += 1) {
        var callback = render_callbacks[i];

        if (!seen_callbacks.has(callback)) {
          callback(); // ...so guard against infinite loops

          seen_callbacks.add(callback);
        }
      }

      render_callbacks.length = 0;
    } while (dirty_components.length);

    while (flush_callbacks.length) {
      flush_callbacks.pop()();
    }

    update_scheduled = false;
  }

  function update($$) {
    if ($$.fragment) {
      $$.update($$.dirty);
      run_all($$.before_update);
      $$.fragment.p($$.dirty, $$.ctx);
      $$.dirty = null;
      $$.after_update.forEach(add_render_callback);
    }
  }

  var outroing = new Set();

  function transition_in(block, local) {
    if (block && block.i) {
      outroing.delete(block);
      block.i(local);
    }
  }

  function get_spread_update(levels, updates) {
    var update = {};
    var to_null_out = {};
    var accounted_for = {
      $$scope: 1
    };
    var i = levels.length;

    while (i--) {
      var o = levels[i];
      var n = updates[i];

      if (n) {
        for (var key in o) {
          if (!(key in n)) to_null_out[key] = 1;
        }

        for (var _key2 in n) {
          if (!accounted_for[_key2]) {
            update[_key2] = n[_key2];
            accounted_for[_key2] = 1;
          }
        }

        levels[i] = n;
      } else {
        for (var _key3 in o) {
          accounted_for[_key3] = 1;
        }
      }
    }

    for (var _key4 in to_null_out) {
      if (!(_key4 in update)) update[_key4] = undefined;
    }

    return update;
  }

  function mount_component(component, target, anchor) {
    var _component$$$ = component.$$,
        fragment = _component$$$.fragment,
        on_mount = _component$$$.on_mount,
        on_destroy = _component$$$.on_destroy,
        after_update = _component$$$.after_update;
    fragment.m(target, anchor); // onMount happens before the initial afterUpdate

    add_render_callback(function () {
      var new_on_destroy = on_mount.map(run).filter(is_function);

      if (on_destroy) {
        on_destroy.push.apply(on_destroy, new_on_destroy);
      } else {
        // Edge case - component was destroyed immediately,
        // most likely as a result of a binding initialising
        run_all(new_on_destroy);
      }

      component.$$.on_mount = [];
    });
    after_update.forEach(add_render_callback);
  }

  function destroy_component(component, detaching) {
    if (component.$$.fragment) {
      run_all(component.$$.on_destroy);
      component.$$.fragment.d(detaching); // TODO null out other refs, including component.$$ (but need to
      // preserve final state?)

      component.$$.on_destroy = component.$$.fragment = null;
      component.$$.ctx = {};
    }
  }

  function make_dirty(component, key) {
    if (!component.$$.dirty) {
      dirty_components.push(component);
      schedule_update();
      component.$$.dirty = blank_object();
    }

    component.$$.dirty[key] = true;
  }

  function init(component, options, instance, create_fragment, not_equal, prop_names) {
    var parent_component = current_component;
    set_current_component(component);
    var props = options.props || {};
    var $$ = component.$$ = {
      fragment: null,
      ctx: null,
      // state
      props: prop_names,
      update: noop,
      not_equal: not_equal,
      bound: blank_object(),
      // lifecycle
      on_mount: [],
      on_destroy: [],
      before_update: [],
      after_update: [],
      context: new Map(parent_component ? parent_component.$$.context : []),
      // everything else
      callbacks: blank_object(),
      dirty: null
    };
    var ready = false;
    $$.ctx = instance ? instance(component, props, function (key, value) {
      if ($$.ctx && not_equal($$.ctx[key], $$.ctx[key] = value)) {
        if ($$.bound[key]) $$.bound[key](value);
        if (ready) make_dirty(component, key);
      }
    }) : props;
    $$.update();
    ready = true;
    run_all($$.before_update);
    $$.fragment = create_fragment($$.ctx);

    if (options.target) {
      if (options.hydrate) {
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        $$.fragment.l(children(options.target));
      } else {
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        $$.fragment.c();
      }

      if (options.intro) transition_in(component.$$.fragment);
      mount_component(component, options.target, options.anchor);
      flush();
    }

    set_current_component(parent_component);
  }

  var SvelteElement;

  if (typeof HTMLElement !== 'undefined') {
    SvelteElement =
    /*#__PURE__*/
    function (_HTMLElement) {
      _inheritsLoose(SvelteElement, _HTMLElement);

      function SvelteElement() {
        var _this;

        _this = _HTMLElement.call(this) || this;

        _this.attachShadow({
          mode: 'open'
        });

        return _this;
      }

      var _proto2 = SvelteElement.prototype;

      _proto2.connectedCallback = function connectedCallback() {
        // @ts-ignore todo: improve typings
        for (var key in this.$$.slotted) {
          // @ts-ignore todo: improve typings
          this.appendChild(this.$$.slotted[key]);
        }
      };

      _proto2.attributeChangedCallback = function attributeChangedCallback(attr, _oldValue, newValue) {
        this[attr] = newValue;
      };

      _proto2.$destroy = function $destroy() {
        destroy_component(this, 1);
        this.$destroy = noop;
      };

      _proto2.$on = function $on(type, callback) {
        // TODO should this delegate to addEventListener?
        var callbacks = this.$$.callbacks[type] || (this.$$.callbacks[type] = []);
        callbacks.push(callback);
        return function () {
          var index = callbacks.indexOf(callback);
          if (index !== -1) callbacks.splice(index, 1);
        };
      };

      _proto2.$set = function $set() {// overridden by instance, if it has props
      };

      return SvelteElement;
    }(_wrapNativeSuper(HTMLElement));
  }

  var SvelteComponent =
  /*#__PURE__*/
  function () {
    function SvelteComponent() {}

    var _proto3 = SvelteComponent.prototype;

    _proto3.$destroy = function $destroy() {
      destroy_component(this, 1);
      this.$destroy = noop;
    };

    _proto3.$on = function $on(type, callback) {
      var callbacks = this.$$.callbacks[type] || (this.$$.callbacks[type] = []);
      callbacks.push(callback);
      return function () {
        var index = callbacks.indexOf(callback);
        if (index !== -1) callbacks.splice(index, 1);
      };
    };

    _proto3.$set = function $set() {// overridden by instance, if it has props
    };

    return SvelteComponent;
  }();

  function create_if_block(ctx) {
    var svg, g1, g0;

    function select_block_type(ctx) {
      if (typeof ctx.i[4] == 'string') return create_if_block_1;
      return create_else_block;
    }

    var current_block_type = select_block_type(ctx);
    var if_block = current_block_type(ctx);
    var svg_levels = [ctx.$$props, {
      style: ctx.s
    }, {
      viewBox: "0 0 " + ctx.i[0] + " " + ctx.i[1]
    }, {
      "aria-hidden": "true"
    }, {
      role: "img"
    }, {
      xmlns: "http://www.w3.org/2000/svg"
    }];
    var svg_data = {};

    for (var i_1 = 0; i_1 < svg_levels.length; i_1 += 1) {
      svg_data = assign(svg_data, svg_levels[i_1]);
    }

    return {
      c: function c() {
        svg = svg_element("svg");
        g1 = svg_element("g");
        g0 = svg_element("g");
        if_block.c();
        attr(g0, "transform", ctx.transform);
        attr(g1, "transform", "translate(256 256)");
        set_attributes(svg, svg_data);
      },
      m: function m(target, anchor) {
        insert(target, svg, anchor);
        append(svg, g1);
        append(g1, g0);
        if_block.m(g0, null);
      },
      p: function p(changed, ctx) {
        if (current_block_type === (current_block_type = select_block_type(ctx)) && if_block) {
          if_block.p(changed, ctx);
        } else {
          if_block.d(1);
          if_block = current_block_type(ctx);

          if (if_block) {
            if_block.c();
            if_block.m(g0, null);
          }
        }

        if (changed.transform) {
          attr(g0, "transform", ctx.transform);
        }

        set_attributes(svg, get_spread_update(svg_levels, [changed.$$props && ctx.$$props, changed.s && {
          style: ctx.s
        }, changed.i && {
          viewBox: "0 0 " + ctx.i[0] + " " + ctx.i[1]
        }, {
          "aria-hidden": "true"
        }, {
          role: "img"
        }, {
          xmlns: "http://www.w3.org/2000/svg"
        }]));
      },
      d: function d(detaching) {
        if (detaching) {
          detach(svg);
        }

        if_block.d();
      }
    };
  } // (120:8) {:else}


  function create_else_block(ctx) {
    var path0, path0_d_value, path0_fill_value, path0_fill_opacity_value, path1, path1_d_value, path1_fill_value, path1_fill_opacity_value;
    return {
      c: function c() {
        path0 = svg_element("path");
        path1 = svg_element("path");
        attr(path0, "d", path0_d_value = ctx.i[4][0]);
        attr(path0, "fill", path0_fill_value = ctx.secondaryColor || ctx.color || 'currentColor');
        attr(path0, "fill-opacity", path0_fill_opacity_value = ctx.swapOpacity != false ? ctx.primaryOpacity : ctx.secondaryOpacity);
        attr(path0, "transform", "translate(-256 -256)");
        attr(path1, "d", path1_d_value = ctx.i[4][1]);
        attr(path1, "fill", path1_fill_value = ctx.primaryColor || ctx.color || 'currentColor');
        attr(path1, "fill-opacity", path1_fill_opacity_value = ctx.swapOpacity != false ? ctx.secondaryOpacity : ctx.primaryOpacity);
        attr(path1, "transform", "translate(-256 -256)");
      },
      m: function m(target, anchor) {
        insert(target, path0, anchor);
        insert(target, path1, anchor);
      },
      p: function p(changed, ctx) {
        if (changed.i && path0_d_value !== (path0_d_value = ctx.i[4][0])) {
          attr(path0, "d", path0_d_value);
        }

        if ((changed.secondaryColor || changed.color) && path0_fill_value !== (path0_fill_value = ctx.secondaryColor || ctx.color || 'currentColor')) {
          attr(path0, "fill", path0_fill_value);
        }

        if ((changed.swapOpacity || changed.primaryOpacity || changed.secondaryOpacity) && path0_fill_opacity_value !== (path0_fill_opacity_value = ctx.swapOpacity != false ? ctx.primaryOpacity : ctx.secondaryOpacity)) {
          attr(path0, "fill-opacity", path0_fill_opacity_value);
        }

        if (changed.i && path1_d_value !== (path1_d_value = ctx.i[4][1])) {
          attr(path1, "d", path1_d_value);
        }

        if ((changed.primaryColor || changed.color) && path1_fill_value !== (path1_fill_value = ctx.primaryColor || ctx.color || 'currentColor')) {
          attr(path1, "fill", path1_fill_value);
        }

        if ((changed.swapOpacity || changed.secondaryOpacity || changed.primaryOpacity) && path1_fill_opacity_value !== (path1_fill_opacity_value = ctx.swapOpacity != false ? ctx.secondaryOpacity : ctx.primaryOpacity)) {
          attr(path1, "fill-opacity", path1_fill_opacity_value);
        }
      },
      d: function d(detaching) {
        if (detaching) {
          detach(path0);
          detach(path1);
        }
      }
    };
  } // (114:8) {#if typeof i[4] == 'string'}


  function create_if_block_1(ctx) {
    var path, path_d_value, path_fill_value;
    return {
      c: function c() {
        path = svg_element("path");
        attr(path, "d", path_d_value = ctx.i[4]);
        attr(path, "fill", path_fill_value = ctx.color || ctx.primaryColor || 'currentColor');
        attr(path, "transform", "translate(-256 -256)");
      },
      m: function m(target, anchor) {
        insert(target, path, anchor);
      },
      p: function p(changed, ctx) {
        if (changed.i && path_d_value !== (path_d_value = ctx.i[4])) {
          attr(path, "d", path_d_value);
        }

        if ((changed.color || changed.primaryColor) && path_fill_value !== (path_fill_value = ctx.color || ctx.primaryColor || 'currentColor')) {
          attr(path, "fill", path_fill_value);
        }
      },
      d: function d(detaching) {
        if (detaching) {
          detach(path);
        }
      }
    };
  }

  function create_fragment(ctx) {
    var if_block_anchor;
    var if_block = ctx.i[4] && create_if_block(ctx);
    return {
      c: function c() {
        if (if_block) if_block.c();
        if_block_anchor = empty();
      },
      m: function m(target, anchor) {
        if (if_block) if_block.m(target, anchor);
        insert(target, if_block_anchor, anchor);
      },
      p: function p(changed, ctx) {
        if (ctx.i[4]) {
          if (if_block) {
            if_block.p(changed, ctx);
          } else {
            if_block = create_if_block(ctx);
            if_block.c();
            if_block.m(if_block_anchor.parentNode, if_block_anchor);
          }
        } else if (if_block) {
          if_block.d(1);
          if_block = null;
        }
      },
      i: noop,
      o: noop,
      d: function d(detaching) {
        if (if_block) if_block.d(detaching);

        if (detaching) {
          detach(if_block_anchor);
        }
      }
    };
  }

  function instance($$self, $$props, $$invalidate) {
    var _ref;

    var _$$props = $$props,
        _$$props$style = _$$props.style,
        style = _$$props$style === void 0 ? '' : _$$props$style,
        icon = _$$props.icon,
        _$$props$fw = _$$props.fw,
        fw = _$$props$fw === void 0 ? false : _$$props$fw,
        _$$props$flip = _$$props.flip,
        flip = _$$props$flip === void 0 ? false : _$$props$flip,
        _$$props$pull = _$$props.pull,
        pull = _$$props$pull === void 0 ? false : _$$props$pull,
        _$$props$rotate = _$$props.rotate,
        rotate = _$$props$rotate === void 0 ? false : _$$props$rotate,
        _$$props$size = _$$props.size,
        size = _$$props$size === void 0 ? false : _$$props$size,
        color = _$$props.color,
        primaryColor = _$$props.primaryColor,
        secondaryColor = _$$props.secondaryColor,
        _$$props$primaryOpaci = _$$props.primaryOpacity,
        primaryOpacity = _$$props$primaryOpaci === void 0 ? 1 : _$$props$primaryOpaci,
        _$$props$secondaryOpa = _$$props.secondaryOpacity,
        secondaryOpacity = _$$props$secondaryOpa === void 0 ? 0.4 : _$$props$secondaryOpa,
        _$$props$swapOpacity = _$$props.swapOpacity,
        swapOpacity = _$$props$swapOpacity === void 0 ? false : _$$props$swapOpacity;
    var i;
    var s;
    var transform;

    $$self.$set = function ($$new_props) {
      $$invalidate('$$props', $$props = assign(assign({}, $$props), $$new_props));
      if ('style' in $$new_props) $$invalidate('style', style = $$new_props.style);
      if ('icon' in $$new_props) $$invalidate('icon', icon = $$new_props.icon);
      if ('fw' in $$new_props) $$invalidate('fw', fw = $$new_props.fw);
      if ('flip' in $$new_props) $$invalidate('flip', flip = $$new_props.flip);
      if ('pull' in $$new_props) $$invalidate('pull', pull = $$new_props.pull);
      if ('rotate' in $$new_props) $$invalidate('rotate', rotate = $$new_props.rotate);
      if ('size' in $$new_props) $$invalidate('size', size = $$new_props.size);
      if ('color' in $$new_props) $$invalidate('color', color = $$new_props.color);
      if ('primaryColor' in $$new_props) $$invalidate('primaryColor', primaryColor = $$new_props.primaryColor);
      if ('secondaryColor' in $$new_props) $$invalidate('secondaryColor', secondaryColor = $$new_props.secondaryColor);
      if ('primaryOpacity' in $$new_props) $$invalidate('primaryOpacity', primaryOpacity = $$new_props.primaryOpacity);
      if ('secondaryOpacity' in $$new_props) $$invalidate('secondaryOpacity', secondaryOpacity = $$new_props.secondaryOpacity);
      if ('swapOpacity' in $$new_props) $$invalidate('swapOpacity', swapOpacity = $$new_props.swapOpacity);
    };

    $$self.$$.update = function ($$dirty) {
      if ($$dirty === void 0) {
        $$dirty = {
          icon: 1,
          fw: 1,
          pull: 1,
          size: 1,
          style: 1,
          flip: 1,
          rotate: 1
        };
      }

      if ($$dirty.icon) {
        $$invalidate('i', i = icon && icon.icon || [0, 0, '', [], '']);
      }

      if ($$dirty.fw || $$dirty.pull || $$dirty.size || $$dirty.style) {
        {
          var _float;

          var width;
          var height = '1em';
          var lineHeight;
          var fontSize;
          var textAlign;
          var verticalAlign = '-.125em';
          var overflow = 'visible';

          if (fw) {
            textAlign = 'center';
            width = '1.25em';
          }

          if (pull) {
            _float = pull;
          }

          if (size) {
            if (size == 'lg') {
              fontSize = '1.33333em';
              lineHeight = '.75em';
              verticalAlign = '-.225em';
            } else if (size == 'xs') {
              fontSize = '.75em';
            } else if (size == 'sm') {
              fontSize = '.875em';
            } else {
              fontSize = size.replace('x', 'em');
            }
          }

          var styleObj = {
            float: _float,
            width: width,
            height: height,
            'line-height': lineHeight,
            'font-size': fontSize,
            'text-align': textAlign,
            'vertical-align': verticalAlign,
            overflow: overflow
          };
          var styleStr = '';

          for (var prop in styleObj) {
            if (styleObj[prop]) {
              styleStr += prop + ":" + styleObj[prop] + ";";
            }
          }

          $$invalidate('s', s = styleStr + style);
        }
      }

      if ($$dirty.flip || $$dirty.rotate) {
        {
          var t = '';

          if (flip) {
            var flipX = 1;
            var flipY = 1;

            if (flip == 'horizontal') {
              flipX = -1;
            } else if (flip == 'vertical') {
              flipY = -1;
            } else {
              flipX = flipY = -1;
            }

            t += " scale(" + flipX + " " + flipY + ")";
          }

          if (rotate) {
            t += " rotate(" + rotate + " 0 0)";
          }

          $$invalidate('transform', transform = t);
        }
      }
    };

    return _ref = {
      style: style,
      icon: icon,
      fw: fw,
      flip: flip,
      pull: pull,
      rotate: rotate,
      size: size,
      color: color,
      primaryColor: primaryColor,
      secondaryColor: secondaryColor,
      primaryOpacity: primaryOpacity,
      secondaryOpacity: secondaryOpacity,
      swapOpacity: swapOpacity,
      i: i,
      s: s,
      transform: transform,
      $$props: $$props
    }, _ref["$$props"] = $$props = exclude_internal_props($$props), _ref;
  }

  var Fa =
  /*#__PURE__*/
  function (_SvelteComponent) {
    _inheritsLoose(Fa, _SvelteComponent);

    function Fa(options) {
      var _this;

      _this = _SvelteComponent.call(this) || this;
      init(_assertThisInitialized(_this), options, instance, create_fragment, safe_not_equal, ["style", "icon", "fw", "flip", "pull", "rotate", "size", "color", "primaryColor", "secondaryColor", "primaryOpacity", "secondaryOpacity", "swapOpacity"]);
      return _this;
    }

    return Fa;
  }(SvelteComponent);

  return Fa;

}());
